function [PolarDataIn]=GenerateHFRosePlotTest()
%
%  [PolarDataIn]=GenerateHFRosePlotTest();
%
% !!!!  see excalmation marks in routine to modify
%
%  Prompt for the directory for the TUV data
%
%  PolarDataIn is the data plotted in the rose plot.  Output in case the
%  use wants to dump it out to a text file.
%
%  Contact Info:  Chris Halle
%                 cmhalle@ucdavis.edu
%
% Code governed by the same public license as the HF Radar Toolbox:
%  Basically, let others know if you update it!
%
% Copyright (C) 2008 Chris Halle
% Licence: GPL (Gnu Public License)
%
NumMinMeasurements=20;  %  number of measurements needed to derive polar plot
%
[TUVFileName,TUVPathName]=uigetfile('*','Select File Containing Currents');
%
load(fullfile(TUVPathName,TUVFileName));
%
%  !!!!  could check for name, but assume name is TUVorig
%
%  don't worry about a real map here - user will not always have one set
%  up.  Can assume web programmer will have one on hand, although it is not
%  always necessary.
%
TemFigHandle=figure;
plot(TUVorig.LonLat(:,1),TUVorig.LonLat(:,2),'bo')
hold
SelectCoord=questdlg('Select the coordinates you would like to investigate.','Site Selection','O.K.','O.K.','O.K.');
[xcoord,ycoord]=ginput(1);
%
%  Prompt for dates
%
prompt={'Year:','Month:','Day:','Hour:','Minute:','Second:'};
name='Start Date:';
numlines=1;
TemDate=round(datevec(TUVorig.TimeStamp(1)));
defaultanswer={num2str(TemDate(1)),num2str(TemDate(2)),num2str(TemDate(3)),...
    num2str(TemDate(4)),num2str(TemDate(5)),num2str(TemDate(6))};
xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
try
    StartDate=[str2num(char(xlimitscell{1}));str2num(char(xlimitscell{2}));...
        str2num(char(xlimitscell{3}));str2num(char(xlimitscell{4}));...
        str2num(char(xlimitscell{5}));str2num(char(xlimitscell{6}))];
    StartDate=StartDate';
catch
    StartDate=TemDate;
end
clear xlimitscell
%
prompt={'Year:','Month:','Day:','Hour:','Minute:','Second:'};
name='End Date:';
numlines=1;
TemDate=round(datevec(TUVorig.TimeStamp(numel(TUVorig.TimeStamp))));
defaultanswer={num2str(TemDate(1)),num2str(TemDate(2)),num2str(TemDate(3)),...
    num2str(TemDate(4)),num2str(TemDate(5)),num2str(TemDate(6))};
xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
try
    EndDate=[str2num(char(xlimitscell{1}));str2num(char(xlimitscell{2}));...
        str2num(char(xlimitscell{3}));str2num(char(xlimitscell{4}));...
        str2num(char(xlimitscell{5}));str2num(char(xlimitscell{6}))];
    EndDate=EndDate';
catch
    EndDate=TemDate;
end
clear xlimitscell
%
%  prompt for times
%
SelectHours=questdlg('Do you wish to select specific hours?','Hour Selection','Yes','No','No');
switch upper(SelectHours)
    case 'YES'
        prompt={'HourStart:','HourEnd:'};
        name='Extract Hours:';
        numlines=1;
        defaultanswer={'0','24'};
        xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
        try
            HourStart=[str2num(char(xlimitscell{1}))];
            HourEnd=[str2num(char(xlimitscell{2}))];
        catch
            HourStart=0;
            HourEnd=24;
        end
        clear xlimitscell
    case 'NO'
        %
        %  do nothing
        %
end
%
%  Trim the currents to match the start and end times
%
TemmarkTime=find((TUVorig.TimeStamp>=datenum(StartDate))&(TUVorig.TimeStamp<=datenum(EndDate)));
if numel(TemmarkTime)>0,
    %
    %  extract the lon/lat and times.  Set up a new structure first,
    %  just in case the old structure had fields that the extraction
    %  routine will not work on
    %
    [NumPoints,NumTimes]=size(TUVorig.U);
    TUVNew=TUVstruct([NumPoints NumTimes],1);
    %
    TUVNew.TimeStamp=TUVorig.TimeStamp;
    TUVNew.LonLat=TUVorig.LonLat;
    TUVNew.U=TUVorig.U;
    TUVNew.V=TUVorig.V;
    %
    TUVNew=subsrefTUV(TUVNew,[1:NumPoints],TemmarkTime);
    %
else
    %
    disp('no measurement times found within time limits specified')
    disp('routine ending')
    return;
end
%
%  Trim to match specific hours, if specified
%
if exist('HourStart','var'),
    %
    TemTime=TUVNew.TimeStamp';
    TemTime=round(datevec(TemTime));
    %
    %  hours go to hour 23, then start over again at hour zero
    %
    if HourEnd<HourStart,
        TemmarkHour=find(TemTime(:,4)<HourStart);
        if numel(TemmarkHour)>0,
            TemTime(:,4)=TemTime(:,4)+24;
        end
        HourEndMod=HourEnd+24;
    else
        HourEndMod=HourEnd;
    end
    %
    TemmarkTime=find((TemTime(:,4)>=HourStart)&(TemTime(:,4)<=HourEndMod));
    %
    if numel(TemmarkTime)>0,
            [NumPoints,NumTimes]=size(TUVNew.U);
            TUVNew=subsrefTUV(TUVNew,[1:NumPoints],TemmarkTime);
    else
        disp('no measurements at the requested hours')
        disp('routine ending')
        return;
    end
end
%
%  Get Closest Measurement
%
NumMeasRemaining=sum(~isnan(TUVNew.U'));
TemmarkMeas=find(NumMeasRemaining>=NumMinMeasurements);
if numel(TemmarkMeas)>0,
    [NumPoints,NumTimes]=size(TUVNew.U);
    TUVNew=subsrefTUV(TUVNew,TemmarkMeas,[1:NumTimes]);
else
    disp('not enough mesurements found')
    disp(['Minimum number of measurements: ' num2str(NumMinMeasurements)])
    disp('routine ending')
    return;
end
%
%  Find the closest measurement to the point requested
%
[s,a12,a21]=m_idist(TUVNew.LonLat(:,1),TUVNew.LonLat(:,2),...
        xcoord,ycoord,'wgs84');
s=s/1000;
[MinPos,MinIndex]=nanmin(s);
%
figure(TemFigHandle);
%
plot(xcoord,ycoord,'r*')
plot(TUVNew.LonLat(MinIndex,1),TUVNew.LonLat(MinIndex,2),'g*')
title('Red - requested location - green - closest location with measurements')
%
ProcessDataSwitch=questdlg('LocationToProcess Shown','Location','O.K.','O.K.','O.K.');
ProcessDataSwitch=questdlg('Continue Processing?','Location','Yes','No','Yes');
switch upper(ProcessDataSwitch)
    case 'NO'
        disp('routine ending')
        return;
    case 'YES'
        % do nothing
end
%
delete(TemFigHandle);
%
EastSeries=TUVNew.U(MinIndex,:);
NorthSeries=TUVNew.V(MinIndex,:);
EastLocation=TUVNew.LonLat(MinIndex,1);
NorthLocation=TUVNew.LonLat(MinIndex,2);
%
MinSpeed=nanmin(abs(EastSeries+i*NorthSeries));
MaxSpeed=nanmax(abs(EastSeries+i*NorthSeries));
if rem(MaxSpeed,10)>0,
    TemMaxSpeedLim=MaxSpeed+(10-rem(MaxSpeed,10));
else
    TemMaxSpeedLim=MaxSpeed;
end
if TemMaxSpeedLim<=10,
    TemMinSpeedLim=0;
else
    TemMinSpeedLim=10;
end
%
%  prompt for the speed and angle limits
%
prompt={'LowSpeedLimit:','HighSpeedLimit:','NumberOfAngleBins:'};
name='Processing Limits';
numlines=1;
defaultanswer={num2str(TemMinSpeedLim),num2str(TemMaxSpeedLim),'8'};
xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
try
    LowSpeedLimit=[str2num(char(xlimitscell{1}))];
    HighSpeedLimit=[str2num(char(xlimitscell{2}))];
    NumberOfAngleBins=[str2num(char(xlimitscell{3}))];
catch
    LowSpeedLimit=TemMinSpeedLim;
    HighSpeedLimit=TemMaxSpeedLim;
    NumberOfAngleBins=8;
end
clear xlimitscell
%
TemmarkSpeed=find(~isnan(EastSeries));
EastSeries=EastSeries(TemmarkSpeed);
NorthSeries=NorthSeries(TemmarkSpeed);
%
SpeedMag=abs(EastSeries+i*NorthSeries);
SpeedIndices=find((SpeedMag>=LowSpeedLimit)&(SpeedMag<=HighSpeedLimit));
if numel(SpeedIndices)>=NumMinMeasurements,
    EastSeriesToAnalyze=EastSeries(SpeedIndices);
    NorthSeriesToAnalyze=NorthSeries(SpeedIndices);
else
    EastSeriesToAnalyze=EastSeries;
    NorthSeriesToAnalyze=NorthSeries;
    disp('not enough measurements in speed limits')
    disp('all measurements used')
    LowSpeedLimit=0;
    HighSpeedLimit=nanmax(abs(EastSeries+i*NorthSeries));
    if rem(HighSpeedLimit,10)>0,
        HighSpeedLimit=HighSpeedLimit+(10-rem(HighSpeedLimit,10));
    end
end
%
[MagOut,DirOut]=ConvertComponentsToSpeedDirRose(EastSeriesToAnalyze,NorthSeriesToAnalyze);
%
SpeedBinEdges=LowSpeedLimit:10:HighSpeedLimit;
if max(SpeedBinEdges)<HighSpeedLimit,
    SpeedBinEdges=[SpeedBinEdges HighSpeedLimit];
end
%
AngleBinEdges=0:360/NumberOfAngleBins:360;
if max(AngleBinEdges)<360,
    AngleBinEdges=[AngleBinEdges 360];
end
%
%  !!!!!!  check on hist routine below
%
[outtable]=myhist2dRose(DirOut,MagOut,AngleBinEdges,SpeedBinEdges);
%
[StatsRows,StatsCols]=size(outtable);
outtable=outtable(1:StatsRows-1,1:StatsCols-1);
%
[StatsRows,StatsCols]=size(outtable);
%
TemCol=AngleBinEdges(1:numel(AngleBinEdges)-1)';
TemCol2=AngleBinEdges(2:numel(AngleBinEdges))';
AngleBins=[TemCol TemCol2];
AngleBins=repmat(AngleBins,StatsCols,1);
%
TemCol=SpeedBinEdges(1:numel(SpeedBinEdges)-1);
TemCol2=SpeedBinEdges(2:numel(SpeedBinEdges));
SpeedMatrixStart=ones(StatsRows,1)*TemCol;
SpeedMatrixEnd=ones(StatsRows,1)*TemCol2;
SpeedMatrixStart=reshape(SpeedMatrixStart,StatsRows*StatsCols,1);
SpeedMatrixEnd=reshape(SpeedMatrixEnd,StatsRows*StatsCols,1);
SpeedBins=[SpeedMatrixStart SpeedMatrixEnd];
%
outtable=reshape(outtable,StatsRows*StatsCols,1);
%
PolarDataIn=[AngleBins SpeedBins outtable];
%
%PolarDataIn=[0 45 10 20 10;0 45 20 30 30;180 225 5 10 60];
%  The following snippet is for the black and white version
[FigHandleOut1]=GenerateHFRosePlot(PolarDataIn);
%
PercentOfMeas=100*(numel(EastSeriesToAnalyze)/numel(EastSeries));
%
TemTitle1=['HF Current Rose, Latitude: ' num2str(NorthLocation) '   Longitude:' num2str(EastLocation)];
TemTitle2=['Analysis of Currents Between ' num2str(min(SpeedMatrixStart))...
    ' and ' num2str(max(SpeedMatrixEnd)) ' cm/s, ' num2str(PercentOfMeas,4)...
    ' Percent of Measurements'];
StartDateStr=datestr(datenum(StartDate),1);
EndDateStr=datestr(datenum(EndDate),1);
if exist('HourStart','var'),
    TemTitle3=['Time Period: ' StartDateStr ' To ' EndDateStr...
        ' Hours ' num2str(HourStart) ' To ' num2str(HourEnd)];
else
    TemTitle3=['Time Period: ' StartDateStr ' To ' EndDateStr...
        ' All Hours '];
end
TemTitleHandle=title({TemTitle1,TemTitle2,TemTitle3});
set(TemTitleHandle,'FontSize',[14])
set(TemTitleHandle,'FontWeight','bold')
%
%  the following snippet is for the color version
%
[FigHandleOut2]=GenerateHFRosePlotColor(PolarDataIn);
%
PercentOfMeas=100*(numel(EastSeriesToAnalyze)/numel(EastSeries));
%
TemTitle1=['HF Current Rose, Latitude: ' num2str(NorthLocation) '   Longitude:' num2str(EastLocation)];
TemTitle2=['Analysis of Currents Between ' num2str(min(SpeedMatrixStart))...
    ' and ' num2str(max(SpeedMatrixEnd)) ' cm/s, ' num2str(PercentOfMeas,4)...
    ' Percent of Measurements'];
StartDateStr=datestr(datenum(StartDate),1);
EndDateStr=datestr(datenum(EndDate),1);
if exist('HourStart','var'),
    TemTitle3=['Time Period: ' StartDateStr ' To ' EndDateStr...
        ' Hours ' num2str(HourStart) ' To ' num2str(HourEnd)];
else
    TemTitle3=['Time Period: ' StartDateStr ' To ' EndDateStr...
        ' All Hours '];
end
TemTitleHandle=title({TemTitle1,TemTitle2,TemTitle3});
set(TemTitleHandle,'FontSize',[14])
set(TemTitleHandle,'FontWeight','bold')
%
%  Prompt for saving the files
%
%  prompt for text file
%
SaveFile=questdlg('Do you wish to save the table?','Save Data?','Yes','No','No');
switch upper(SaveFile)
    case 'YES'
        prompt={'Enter Name:'};
        name='File Name:';
        numlines=1;
        defaultanswer={'PolarDataText.txt'};
        xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
        try
            FileNameOut=char(xlimitscell{1});
        catch
            FileNameOut='PolarDataText.txt';
        end
        clear xlimitscell
        %
        cd(TUVPathName);
        if exist(FileNameOut,'file'),
            disp('File Name Exists')
            FileNameOut=['HFPolar' datestr(now,30) '.txt'];
            TemStr=['Name Changed To: ' FileNameOut];
            disp(TemStr)
        end
        %
        PutOutTextFileRose({TemTitle1;TemTitle2;TemTitle3},PolarDataIn,FileNameOut);
        %
    case 'NO'
        %
        %  do nothing
        %
end
%
%  Check to save black and white figure
%
figure(FigHandleOut1);  % just switching to this figure on the screen.
%
SaveFile=questdlg('Do you wish to save the b/w figure?','Save Figure?','Yes','No','No');
switch upper(SaveFile)
    case 'YES'
        prompt={'Enter Name:'};
        name='File Name:';
        numlines=1;
        defaultanswer={'BlackWhitePolar.jpg'};
        xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
        try
            FileNameOut=char(xlimitscell{1});
        catch
            FileNameOut='BlackWhitePolar.jpg';
        end
        clear xlimitscell
        %
        cd(TUVPathName);
        %
        if exist(FileNameOut,'file'),
            disp('File Name Exists')
            FileNameOut=['BlackWhitePolar' datestr(now,30) '.jpg'];
            TemStr=['Name Changed To: ' FileNameOut];
            disp(TemStr)
        end
        %
        saveas(FigHandleOut1,FileNameOut,'jpg');
        %
    case 'NO'
        %
        %  do nothing
        %
end
%
%  prompt to save the color version
%
figure(FigHandleOut2);  % just switching to this figure on the screen.
%
SaveFile=questdlg('Do you wish to save the color figure?','Save Figure?','Yes','No','No');
switch upper(SaveFile)
    case 'YES'
        prompt={'Enter Name:'};
        name='File Name:';
        numlines=1;
        defaultanswer={'ColorPolar.jpg'};
        xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
        try
            FileNameOut=char(xlimitscell{1});
        catch
            FileNameOut='ColorPolar.jpg';
        end
        clear xlimitscell
        %
        cd(TUVPathName);
        %
        if exist(FileNameOut,'file'),
            disp('File Name Exists')
            FileNameOut=['ColorPolar' datestr(now,30) '.jpg'];
            TemStr=['Name Changed To: ' FileNameOut];
            disp(TemStr)
        end
        %
        saveas(FigHandleOut2,FileNameOut,'jpg');
        %
    case 'NO'
        %
        %  do nothing
        %
end
%
return;
%

