function [outtable]=myhist2dRose(data1,data2,binedges1,binedges2)
%
%  [outtable]=myhist2dRose(data1,data2,binedges1,binedges2)
%
%  This creates a 2d histogram, using the bins specified by binedges.
%  Each value in data1 is associated with the corresponding value in data2.
%
%  a row is added to the bottom which sums down the columns
%  a row is added to the end which sums across rows
%
%  down the rows is increasing values of data1, across the columns
%  is increasing values of data2
%
%  CMH
%
%  data can be specified in either row or column format.  It is converted to row format
%  within the rotuine just to make sure that some of the later statements
%  will work.
%
%  Percentages are returned rather than counts.  The lower right corner of the table should
%  be equal to 100%.  If not, it is just due to roundoff error.
%
%
%  Contact Info:  Chris Halle
%                 cmhalle@ucdavis.edu
%
% Code governed by the same public license as the HF Radar Toolbox:
%  Basically, let others know if you update it!
%
% Copyright (C) 2008 Chris Halle
% Licence: GPL (Gnu Public License)
%
[mn,nn]=size(data1);
if mn>nn,
    data1=data1';
end
%
[mn,nn]=size(data2);
if mn>nn,
    data2=data2';
end
%
[mn,nn]=size(binedges1);
if mn>nn,
    binedges1=binedges1';
end
%
[mn,nn]=size(binedges2);
if mn>nn,
    binedges2=binedges2';
end
%
%  Now start calculating the table
%
m1=max(size(binedges1));
m2=max(size(binedges2));
outtable=zeros(m1-1,m2-1);
%
for jm=1:m1-1,
    if jm<m1-1,
        temmark=find((data1>=binedges1(jm))&(data1<binedges1(jm+1)));
    else
        temmark=find((data1>=binedges1(jm))&(data1<=binedges1(jm+1)));
    end
%
    mt=min(size(temmark));
    if mt>0,
        temhist=histc(data2(temmark),binedges2);
        outtable(jm,:)=temhist(1:m2-1);
    end
end
%
%  get sums down columns and across rows, and add to the table
%
totdowncols=sum(outtable);
outtable=[outtable;totdowncols];
%
totacrossrows=sum(outtable');
totacrossrows=totacrossrows';
outtable=[outtable totacrossrows];
%
%  convert to percents
%
maxcount=max(max(outtable));
outtable=(100/maxcount)*outtable;
%
%  the routine is done
%
